@@ -94,8 +94,19 @@ class AutoFeaturizer(DFTransformer):
             state.
         multiiindex (bool): If True, returns a multiindexed dataframe. Not
             recommended for use in MatPipe.
+        do_precheck (bool): Execute a precheck on each featurizer before
+            featurizing with it. See matminer prechecking for more info.
         n_jobs (int): The number of parallel jobs to use during featurization
             for each featurizer. Default is n_cores
+                composition_col="composition",
+        composition_col (str): Name of the column containing structures to be
+            featurized.
+        structure_col (str)L Name of the column containing structures to be
+            featurized
+        bandstructure (str): Name of the column containing bandstructures to
+            be featurized.
+        dos_col (str): Name of the column containing density of states obejcts
+            to be featurized.
 
     Attributes:
         These attributes are set during fitting
@@ -374,7 +385,7 @@ class AutoFeaturizer(DFTransformer):
 
     @log_progress(logger, AMM_LOG_TRANSFORM_STR)
     @check_fitted
-    def transform(self, df, target):
+    def transform(self, df, target, prevent_cache_overwrite=False):
         """
         Decorate a dataframe containing composition, structure, bandstructure,
         and/or DOS objects with descriptors.
@@ -382,6 +393,8 @@ class AutoFeaturizer(DFTransformer):
         Args:
             df (pandas.DataFrame): The dataframe not containing features.
             target (str): The ML-target property contained in the df.
+            prevent_cache_overwrite (bool): If True, does not try to write any
+                new features to the cache.
 
         Returns:
             df (pandas.DataFrame): Transformed dataframe containing features.
@@ -490,7 +503,11 @@ class AutoFeaturizer(DFTransformer):
                     multiindex=self.multiindex,
                     inplace=False,
                 )
-            if self.cache_src and not os.path.exists(self.cache_src):
+            if (
+                self.cache_src
+                and not os.path.exists(self.cache_src)
+                and not prevent_cache_overwrite
+            ):
                 store_dataframe_as_json(df, self.cache_src)
             return df
 
@@ -586,14 +603,9 @@ class AutoFeaturizer(DFTransformer):
                 except Exception as e:
                     logger.warning(
                         self._log_prefix + "Could not decorate oxidation states due "
-                        "to {}. Excluding featurizers based on "
-                        "composition oxistates".format(e)
+                        "to {}. Some featurizers based on composition oxidstates"
+                        "may not work".format(e)
                     )
-                    classes_require_oxi = [
-                        c.__class__.__name__
-                        for c in CompositionFeaturizers().need_oxi
-                    ]
-                    self.exclude.extend(classes_require_oxi)
 
         else:
             # Convert structure/bs/dos dicts to objects (robust already)
